=== modified file 'drizzled/common.h'
--- drizzled/common.h	2009-03-31 07:57:46 +0000
+++ drizzled/common.h	2009-04-03 20:40:31 +0000
@@ -364,7 +364,4 @@
 #define NET_HEADER_SIZE 4		/* standard header size */
 #define COMP_HEADER_SIZE 3		/* compression header extra size */
 
-
-#define NULL_LENGTH UINT32_MAX /* For drizzleclient_net_store_length */
-
 #endif

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-04-03 18:58:58 +0000
+++ drizzled/drizzled.cc	2009-04-03 20:40:31 +0000
@@ -28,7 +28,6 @@
 #include <signal.h>
 
 #include <mysys/my_bit.h>
-#include <libdrizzleclient/libdrizzle.h>
 #include <mysys/hash.h>
 #include <drizzled/stacktrace.h>
 #include <mysys/mysys_err.h>
@@ -64,7 +63,6 @@
 #include <sys/prctl.h>
 #endif
 
-#include <libdrizzleclient/errmsg.h>
 #include <locale.h>
 
 #define mysqld_charset &my_charset_utf8_general_ci
@@ -1966,7 +1964,8 @@
       close(new_sock);
       continue;
     }
-    if (drizzleclient_net_init_sock(&session->net, new_sock, sock == 0))
+
+    if (session->protocol->init_file_descriptor(new_sock))
     {
       delete session;
       continue;

=== modified file 'drizzled/protocol.cc'
--- drizzled/protocol.cc	2009-02-21 00:18:15 +0000
+++ drizzled/protocol.cc	2009-04-03 20:40:31 +0000
@@ -274,8 +274,8 @@
 
   /* The first # is to make the protocol backward compatible */
   buff[2]= '#';
-  pos= (unsigned char*) strcpy((char*) buff+3, drizzleclient_errno_to_sqlstate(sql_errno));
-  pos+= strlen(drizzleclient_errno_to_sqlstate(sql_errno));
+  pos= (unsigned char*) strcpy((char*) buff+3, drizzle_errno_to_sqlstate(sql_errno));
+  pos+= strlen(drizzle_errno_to_sqlstate(sql_errno));
 
   char *tmp= strncpy((char*)pos, err, DRIZZLE_ERRMSG_SIZE-1);
   tmp+= strlen((char*)pos);
@@ -645,6 +645,13 @@
   All data are sent as 'packed-string-length' followed by 'string-data'
 ****************************************************************************/
 
+bool Protocol_text::init_file_descriptor(int fd)
+{
+  if (drizzleclient_net_init_sock(&session->net, fd, 0))
+    return true;
+  return false;
+}
+
 void Protocol_text::prepare_for_resend()
 {
   packet->length(0);

=== modified file 'drizzled/protocol.h'
--- drizzled/protocol.h	2009-02-08 11:11:30 +0000
+++ drizzled/protocol.h	2009-04-03 20:40:31 +0000
@@ -75,6 +75,8 @@
     return 0;
   }
   virtual bool flush();
+
+  virtual bool init_file_descriptor(int fd)=0;
   virtual void prepare_for_resend()=0;
 
   virtual bool store_null()=0;
@@ -112,6 +114,7 @@
 public:
   Protocol_text() {}
   Protocol_text(Session *session_arg) :Protocol(session_arg) {}
+  virtual bool init_file_descriptor(int fd);
   virtual void prepare_for_resend();
   virtual bool store(I_List<i_string> *str_list)
   {

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2009-03-25 22:52:34 +0000
+++ drizzled/session.h	2009-04-03 20:40:31 +0000
@@ -25,6 +25,7 @@
 
 #include <drizzled/protocol.h>
 #include <libdrizzleclient/password.h>     // rand_struct
+#include <libdrizzleclient/net_serv.h>     // NET
 #include <drizzled/sql_locale.h>
 #include <drizzled/ha_trx_info.h>
 #include <mysys/my_tree.h>

=== modified file 'drizzled/sql_alloc.h'
--- drizzled/sql_alloc.h	2009-02-02 19:40:04 +0000
+++ drizzled/sql_alloc.h	2009-04-03 20:40:31 +0000
@@ -20,7 +20,6 @@
 #ifndef DRIZZLE_SERVER_SQL_ALLOC_H
 #define DRIZZLE_SERVER_SQL_ALLOC_H
 
-#include <libdrizzleclient/net_serv.h>
 #include <mysys/my_alloc.h>
 #include <mystrings/m_ctype.h>
 
@@ -39,7 +38,6 @@
                                const CHARSET_INFO * const to_cs,
                                size_t *result_length);
 void sql_kill(Session *session, ulong id, bool only_kill_query);
-bool net_request_file(NET* net, const char* fname);
 char* query_table_status(Session *session,const char *db,const char *table_name);
 
 /* mysql standard class memory allocator */

=== modified file 'drizzled/sql_state.cc'
--- drizzled/sql_state.cc	2009-02-08 11:28:58 +0000
+++ drizzled/sql_state.cc	2009-04-03 20:40:31 +0000
@@ -31,7 +31,7 @@
 
 typedef struct st_map_errno_to_sqlstate
 {
-  uint32_t drizzleclient_errno;
+  uint32_t drizzle_errno;
   const char *odbc_state;
   const char *jdbc_state;
 } errno_sqlstate_map;
@@ -249,19 +249,19 @@
 bool compare_errno_map(errno_sqlstate_map a,
                        errno_sqlstate_map b)
 {
-  return (a.drizzleclient_errno < b.drizzleclient_errno);
+  return (a.drizzle_errno < b.drizzle_errno);
 }
 
-const char *drizzleclient_errno_to_sqlstate(uint32_t drizzleclient_errno)
+const char *drizzle_errno_to_sqlstate(uint32_t drizzle_errno)
 {
 
-  errno_sqlstate_map drizzle_err_state= {drizzleclient_errno, NULL, NULL};
+  errno_sqlstate_map drizzle_err_state= {drizzle_errno, NULL, NULL};
   errno_sqlstate_map* result=
     lower_bound(&sqlstate_map[0],
                 &sqlstate_map[sizeof(sqlstate_map)/sizeof(*sqlstate_map)],
                 drizzle_err_state, compare_errno_map);
 
-  if ((*result).drizzleclient_errno == drizzleclient_errno)
+  if ((*result).drizzle_errno == drizzle_errno)
     return (*result).odbc_state;
   /* General error */
   return "HY000";

=== modified file 'drizzled/sql_state.h'
--- drizzled/sql_state.h	2009-02-08 11:28:58 +0000
+++ drizzled/sql_state.h	2009-04-03 20:40:31 +0000
@@ -20,6 +20,6 @@
 #ifndef _drizzled_sql_state_h
 #define _drizzled_sql_state_h
 
-const char *drizzleclient_errno_to_sqlstate(uint32_t drizzleclient_errno);
+const char *drizzle_errno_to_sqlstate(uint32_t drizzle_errno);
 
 #endif

=== modified file 'libdrizzleclient/pack.h'
--- libdrizzleclient/pack.h	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/pack.h	2009-04-03 20:40:31 +0000
@@ -22,6 +22,8 @@
 
 #include <stdint.h>
 
+#define NULL_LENGTH UINT32_MAX
+
 #ifdef __cplusplus
 extern "C" {
 #endif

